@@ -1,7 +1,7 @@
 require 'spec_helper'
 
 describe GrapePathHelpers::AllRoutes do
-  Grape::API.extend described_class
+  Grape::API::Instance.extend described_class
 
   describe '#all_routes' do
     context 'when API is mounted within another API' do
@@ -11,7 +11,7 @@ describe GrapePathHelpers::AllRoutes do
         mounting_api
 
         # A route is unique if no other route shares the same set of options
-        all_route_options = Grape::API.all_routes.map do |r|
+        all_route_options = Grape::API::Instance.all_routes.map do |r|
           r.instance_variable_get(:@options).merge(path: r.path)
         end
 
@@ -28,7 +28,7 @@ describe GrapePathHelpers::AllRoutes do
       it 'returns all POST routes' do
         expected_routes = Spec::Support::MultiplePostsAPI.routes.map(&:path)
 
-        all_routes = Grape::API.all_routes
+        all_routes = Grape::API::Instance.all_routes
         expect(all_routes.map(&:path)).to include(*expected_routes)
       end
     end
